@@ -18,7 +18,7 @@ class ma_income_tax_before_credits(Variable):
         )
         part_b = tax_unit("ma_part_b_taxable_income", period)
         part_c = tax_unit("ma_part_c_taxable_income", period)
-        rates = parameters(period).states.ma.tax.income.rates
+        rates = parameters(period).gov.states.ma.tax.income.rates
         exempt = tax_unit("is_ma_income_tax_exempt", period)
         tax_on_income = (
             rates.part_a_interest_dividends * part_a_interest_dividends
