@@ -10,7 +10,7 @@ class snap_max_allotment(Variable):
     unit = USD
 
     def formula(spm_unit, period, parameters):
-        max_allotments = parameters(period).usda.snap.max_allotment
+        max_allotments = parameters(period).gov.usda.snap.max_allotment
         MAX_HOUSEHOLD_SIZE_UNDER_MAIN = 8
         snap_region = spm_unit.household("snap_region_str", period)
         household_size = min_(
